diff --git a/osu.Game/Overlays/BeatmapSet/Scores/ScoreTable.cs b/osu.Game/Overlays/BeatmapSet/Scores/ScoreTable.cs
index b2e5be6601..669b701d1d 100644
--- a/osu.Game/Overlays/BeatmapSet/Scores/ScoreTable.cs
+++ b/osu.Game/Overlays/BeatmapSet/Scores/ScoreTable.cs
@@ -168,7 +168,7 @@ namespace osu.Game.Overlays.BeatmapSet.Scores
new UpdateableFlag(score.User.Country)
{
Size = new Vector2(19, 14),
- ShowPlaceholderOnNull = false,
+ ShowPlaceholderOnUnknown = false,
},
username,
new OsuSpriteText
diff --git a/osu.Game/Overlays/BeatmapSet/Scores/TopScoreUserSection.cs b/osu.Game/Overlays/BeatmapSet/Scores/TopScoreUserSection.cs
index f093c6b53f..85c8f92a76 100644
--- a/osu.Game/Overlays/BeatmapSet/Scores/TopScoreUserSection.cs
+++ b/osu.Game/Overlays/BeatmapSet/Scores/TopScoreUserSection.cs
@@ -120,7 +120,7 @@ namespace osu.Game.Overlays.BeatmapSet.Scores
Origin = Anchor.CentreLeft,
Size = new Vector2(19, 14),
Margin = new MarginPadding { Top = 3 }, // makes spacing look more even
- ShowPlaceholderOnNull = false,
+ ShowPlaceholderOnUnknown = false,
},
}
}
diff --git a/osu.Game/Overlays/Profile/Header/TopHeaderContainer.cs b/osu.Game/Overlays/Profile/Header/TopHeaderContainer.cs
index 818a84b9aa..a213f99701 100644
--- a/osu.Game/Overlays/Profile/Header/TopHeaderContainer.cs
+++ b/osu.Game/Overlays/Profile/Header/TopHeaderContainer.cs
@@ -137,7 +137,7 @@ namespace osu.Game.Overlays.Profile.Header
userFlag = new UpdateableFlag
{
Size = new Vector2(28, 20),
- ShowPlaceholderOnNull = false,
+ ShowPlaceholderOnUnknown = false,
},
userCountryText = new OsuSpriteText
{
diff --git a/osu.Game/Overlays/Rankings/Tables/RankingsTable.cs b/osu.Game/Overlays/Rankings/Tables/RankingsTable.cs
index 56e318637a..1e33b96ef1 100644
--- a/osu.Game/Overlays/Rankings/Tables/RankingsTable.cs
+++ b/osu.Game/Overlays/Rankings/Tables/RankingsTable.cs
@@ -100,7 +100,7 @@ namespace osu.Game.Overlays.Rankings.Tables
new UpdateableFlag(GetCountry(item))
{
Size = new Vector2(28, 20),
- ShowPlaceholderOnNull = false,
+ ShowPlaceholderOnUnknown = false,
},
CreateFlagContent(item)
}
diff --git a/osu.Game/Users/Drawables/UpdateableFlag.cs b/osu.Game/Users/Drawables/UpdateableFlag.cs
index 2f08f1c787..88c08d4bb1 100644
--- a/osu.Game/Users/Drawables/UpdateableFlag.cs
+++ b/osu.Game/Users/Drawables/UpdateableFlag.cs
@@ -22,9 +22,9 @@ namespace osu.Game.Users.Drawables
}
///
/// Whether to show a place holder on null country.
///
- public bool ShowPlaceholderOnNull = true;
+ public bool ShowPlaceholderOnUnknown = true;
///
/// Perform an action in addition to showing the country ranking.
@@ -39,7 +39,7 @@ namespace osu.Game.Users.Drawables
protected override Drawable CreateDrawable(Country country)
{
- if (country == default && !ShowPlaceholderOnNull)
+ if (country == default && !ShowPlaceholderOnUnknown)
return null;
return new Container
@@ -22,9 +22,9 @@ namespace osu.Game.Users.Drawables
}
///
- /// Whether to show a place holder on null country.
+ /// Whether to show a place holder on unknown country.
///